@@ -3,7 +3,7 @@ import glob
 import os
 import logging
 
-from .process import process
+from .process import process, rename, ObjectType
 
 
 def main():
@@ -16,6 +16,7 @@ def main():
     ap.add_argument('--output-prefix', type=str, default='.', help="Output path prefix")
     args = ap.parse_args()
 
+    os.makedirs(args.output_prefix, exist_ok=True)
     file_handler = logging.FileHandler(os.path.join(args.output_prefix, 'verification.log'), 'w')
     file_handler.setLevel(logging.ERROR)
 
@@ -63,6 +64,33 @@ def main():
         all_contents.append(contents)
 
     results, msgs = process(all_contents, files)
+
+    output_files = []
+    for file_path in files:
+        if arg == 'p':
+            splits = os.path.split(file_path)
+            output_splits = []
+            for i, s in enumerate(splits):
+                out_s = rename(s, ObjectType.FUNCTION)
+                if out_s != s:
+                    if i == len(splits) - 1:
+                        msgs.append({'type': 'rename_file',
+                                     'old_file': s,
+                                     'new_file': out_s})
+                    else:
+                        msgs.append({'type': 'rename_directory',
+                                     'old_dir': s,
+                                     'new_dir': out_s})
+                output_splits.append(out_s)
+
+            output_file_path = os.path.join(args.output_prefix, *output_splits)
+        else:
+            output_file_path = os.path.join(args.output_prefix, file_path)
+
+        output_files.append(output_file_path)
+
+    msgs = [m for i, m in enumerate(msgs) if m not in msgs[:i]]
+
     for msg in msgs:
         if msg['type'] == 'rename':
             logging.error('{file_path}: {line} - {object_type} NAMING ERROR: {old_token} should be {new_token}'
@@ -71,10 +99,13 @@ def main():
             logging.error('{file_path}: {line} - NAMING IN DOCSTRING ERROR'.format(**msg))
         if msg['type'] == 'add_docstring':
             logging.error('{file_path}: {line} - MISSING DOCSTRING ERROR'.format(**msg))
+        if msg['type'] == 'rename_file':
+            logging.error('{old_file} - FILENAME ERROR: should be {new_file}'.format(**msg))
+        if msg['type'] == 'rename_directory':
+            logging.error('{old_dir} - DIRECTORY NAME ERROR: should be {new_dir}'.format(**msg))
 
     if mode == 'output':
-        for file_path, fixed in zip(files, results):
-            output_file_path = os.path.join(args.output_prefix, file_path)
+        for output_file_path, file_path, fixed in zip(output_files, files, results):
             output_file_folder = os.sep.join(output_file_path.split(os.sep)[:-1])
             os.makedirs(output_file_folder, exist_ok=True)
             with open(output_file_path, 'w') as file:
@@ -88,4 +119,8 @@ def main():
                     lines.append('{file_path}: {line} - fixed naming in docstring\n'.format(**msg))
                 if msg['type'] == 'add_docstring':
                     lines.append('{file_path}: {line} - added docstring\n'.format(**msg))
+                if msg['type'] == 'rename_file':
+                    lines.append('{old_file} - FILENAME ERROR: renamed to {new_file}'.format(**msg))
+                if msg['type'] == 'rename_directory':
+                    lines.append('{old_dir} - DIRECTORY NAME ERROR: renamed to {new_dir}'.format(**msg))
             file.writelines(lines)
